package
Version:
v0.0.0-...-7ff6432
Opens a new window with list of versions in this module.
Published: Apr 20, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Sample struct {
Filename string `json:"filename"`
Lines []string `json:"lines"`
}
Sample is the first few lines of an input file, shipped to the client
so it can drive the FS picker / field labeller helpers.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.